@@ -5,15 +5,20 @@ from benedict.serializers.base64 import Base64Serializer
 from benedict.serializers.csv import CSVSerializer
 from benedict.serializers.json import JSONSerializer
 from benedict.serializers.pickle import PickleSerializer
+from benedict.serializers.plist import PListSerializer
 from benedict.serializers.query_string import QueryStringSerializer
 from benedict.serializers.toml import TOMLSerializer
 from benedict.serializers.xml import XMLSerializer
 from benedict.serializers.yaml import YAMLSerializer
 
+import re
+
+
 _BASE64_SERIALIZER = Base64Serializer()
 _CSV_SERIALIZER = CSVSerializer()
 _JSON_SERIALIZER = JSONSerializer()
 _PICKLE_SERIALIZER = PickleSerializer()
+_PLIST_SERIALIZER = PListSerializer()
 _QUERY_STRING_SERIALIZER = QueryStringSerializer()
 _TOML_SERIALIZER = TOMLSerializer()
 _YAML_SERIALIZER = YAMLSerializer()
@@ -25,10 +30,9 @@ _SERIALIZERS = {
     'csv': _CSV_SERIALIZER,
     'json': _JSON_SERIALIZER,
     'pickle': _PICKLE_SERIALIZER,
+    'plist': _PLIST_SERIALIZER,
     'qs': _QUERY_STRING_SERIALIZER,
     'querystring': _QUERY_STRING_SERIALIZER,
-    'query-string': _QUERY_STRING_SERIALIZER,
-    'query_string': _QUERY_STRING_SERIALIZER,
     'toml': _TOML_SERIALIZER,
     'yaml': _YAML_SERIALIZER,
     'yml': _YAML_SERIALIZER,
@@ -48,7 +52,9 @@ def get_format_by_path(path):
 
 
 def get_serializer_by_format(format):
-    return _SERIALIZERS.get((format or '').lower().replace(' ', '_'))
+    format_key = (format or '').lower().strip()
+    format_key = re.sub(r'[\s\-\_]*', '', format_key)
+    return _SERIALIZERS.get(format_key)
 
 
 def get_serializers_extensions():
